************
User's Guide
************

Welcome to the user guide for SunPy. SunPy is a community-developed, free and
open-source solar data analysis environment. It is meant to provide
the core functionality and tools to analyze solar data with Python.
This guide provides a walkthrough of the major features in SunPy.
For more details checkout the :ref:`reference`.

.. toctree::
   :maxdepth: 3

   installation/index
   Brief Tour <tour>
   Data Acquisition <acquiring_data/index>
   Data Types <data_types/index>
   Plotting <plotting>
   Units and Coordinates <units-coordinates>
   Time <time>
   customization
   logger
   ssw
   troubleshooting
